/*
dotNetRDF is free and open source software licensed under the MIT License

-----------------------------------------------------------------------------

Copyright (c) 2009-2012 dotNetRDF Project (dotnetrdf-developer@lists.sf.net)

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is furnished
to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

#if NO_WEB

namespace VDS.RDF.Writing
{
    /// <summary>
    /// HTML Tags
    /// </summary>
    public enum HtmlTextWriterTag
    {
        /// <summary>
        /// Unknown
        /// </summary>
        Unknown,
        /// <summary>
        /// Link
        /// </summary>
        A,
        /// <summary>
        /// Acronym
        /// </summary>
        Acronym,
        /// <summary>
        /// Address
        /// </summary>
        Address,
        /// <summary>
        /// Area
        /// </summary>
        Area,
        /// <summary>
        /// Bold
        /// </summary>
        B,
        /// <summary>
        /// Base URI
        /// </summary>
        Base,
        /// <summary>
        /// Base Font
        /// </summary>
        Basefont,
        /// <summary>
        /// Bidirectional
        /// </summary>
        Bdo,
        /// <summary>
        /// Background Sound
        /// </summary>
        Bgsound,
        /// <summary>
        /// Big
        /// </summary>
        Big,
        /// <summary>
        /// Block Quotes
        /// </summary>
        Blockquote,
        /// <summary>
        /// Body
        /// </summary>
        Body,
        /// <summary>
        /// Line Break
        /// </summary>
        Br,
        /// <summary>
        /// Button
        /// </summary>
        Button,
        /// <summary>
        /// Caption
        /// </summary>
        Caption,
        /// <summary>
        /// Centering
        /// </summary>
        Center,
        /// <summary>
        /// Citation
        /// </summary>
        Cite,
        /// <summary>
        /// Code
        /// </summary>
        Code,
        /// <summary>
        /// Column
        /// </summary>
        Col,
        /// <summary>
        /// Column Group
        /// </summary>
        Colgroup,
        /// <summary>
        /// Data Definition
        /// </summary>
        Dd,
        /// <summary>
        /// Deleted
        /// </summary>
        Del,
        /// <summary>
        /// Definition
        /// </summary>
        Dfn,
        /// <summary>
        /// Direction
        /// </summary>
        Dir,
        /// <summary>
        /// Div
        /// </summary>
        Div,
        /// <summary>
        /// Dl
        /// </summary>
        Dl,
        /// <summary>
        /// Dt
        /// </summary>
        Dt,
        /// <summary>
        /// Emphasis
        /// </summary>
        Em,
        /// <summary>
        /// Embed
        /// </summary>
        Embed,
        /// <summary>
        /// Field Set
        /// </summary>
        Fieldset,
        /// <summary>
        /// Font
        /// </summary>
        Font,
        /// <summary>
        /// Form
        /// </summary>
        Form,
        /// <summary>
        /// Frame
        /// </summary>
        Frame,
        /// <summary>
        /// Frame Set
        /// </summary>
        Frameset,
        /// <summary>
        /// Heading 1
        /// </summary>
        H1,
        /// <summary>
        /// Heading 2
        /// </summary>
        H2,
        /// <summary>
        /// Heading 3
        /// </summary>
        H3,
        /// <summary>
        /// Heading 4
        /// </summary>
        H4,
        /// <summary>
        /// Heading 5
        /// </summary>
        H5,
        /// <summary>
        /// Heading 6
        /// </summary>
        H6,
        /// <summary>
        /// Head
        /// </summary>
        Head,
        /// <summary>
        /// Horizontal Rule
        /// </summary>
        Hr,
        /// <summary>
        /// HTML
        /// </summary>
        Html,
        /// <summary>
        /// Italics
        /// </summary>
        I,
        /// <summary>
        /// Inline Frame
        /// </summary>
        Iframe,
        /// <summary>
        /// Image
        /// </summary>
        Img,
        /// <summary>
        /// Form Input
        /// </summary>
        Input,
        /// <summary>
        /// Inserted
        /// </summary>
        Ins,
        /// <summary>
        /// Is Index
        /// </summary>
        Isindex,
        /// <summary>
        /// Keyboard
        /// </summary>
        Kbd,
        /// <summary>
        /// Label
        /// </summary>
        Label,
        /// <summary>
        /// Legend
        /// </summary>
        Legend,
        /// <summary>
        /// List Item
        /// </summary>
        Li,
        /// <summary>
        /// Link
        /// </summary>
        Link,
        /// <summary>
        /// Map
        /// </summary>
        Map,
        /// <summary>
        /// Marquee
        /// </summary>
        Marquee,
        /// <summary>
        /// Menu
        /// </summary>
        Menu,
        /// <summary>
        /// Metadata
        /// </summary>
        Meta,
        /// <summary>
        /// Nobr
        /// </summary>
        Nobr,
        /// <summary>
        /// No Frames
        /// </summary>
        Noframes,
        /// <summary>
        /// No Script
        /// </summary>
        Noscript,
        /// <summary>
        /// Object
        /// </summary>
        Object,
        /// <summary>
        /// Ordered List
        /// </summary>
        Ol,
        /// <summary>
        /// Option
        /// </summary>
        Option,
        /// <summary>
        /// Paragraph
        /// </summary>
        P,
        /// <summary>
        /// Param
        /// </summary>
        Param,
        /// <summary>
        /// Pre-formatted
        /// </summary>
        Pre,
        /// <summary>
        /// Q
        /// </summary>
        Q,
        /// <summary>
        /// Rt
        /// </summary>
        Rt,
        /// <summary>
        /// Ruby
        /// </summary>
        Ruby,
        /// <summary>
        /// Strike-through
        /// </summary>
        S,
        /// <summary>
        /// Sample
        /// </summary>
        Samp,
        /// <summary>
        /// Script
        /// </summary>
        Script,
        /// <summary>
        /// Select
        /// </summary>
        Select,
        /// <summary>
        /// Small
        /// </summary>
        Small,
        /// <summary>
        /// Span
        /// </summary>
        Span,
        /// <summary>
        /// Strike
        /// </summary>
        Strike,
        /// <summary>
        /// Strong
        /// </summary>
        Strong,
        /// <summary>
        /// CSS Styles
        /// </summary>
        Style,
        /// <summary>
        /// Subscript
        /// </summary>
        Sub,
        /// <summary>
        /// Superscript
        /// </summary>
        Sup,
        /// <summary>
        /// Table
        /// </summary>
        Table,
        /// <summary>
        /// Table Body
        /// </summary>
        Tbody,
        /// <summary>
        /// Table Column
        /// </summary>
        Td,
        /// <summary>
        /// Text Area
        /// </summary>
        Textarea,
        /// <summary>
        /// Table Footer
        /// </summary>
        Tfoot,
        /// <summary>
        /// Table Column Header
        /// </summary>
        Th,
        /// <summary>
        /// Table Head
        /// </summary>
        Thead,
        /// <summary>
        /// Title
        /// </summary>
        Title,
        /// <summary>
        /// Table Row
        /// </summary>
        Tr,
        /// <summary>
        /// Teletype
        /// </summary>
        Tt,
        /// <summary>
        /// Underline
        /// </summary>
        U,
        /// <summary>
        /// Unordered List
        /// </summary>
        Ul,
        /// <summary>
        /// Var
        /// </summary>
        Var,
        /// <summary>
        /// Wbr
        /// </summary>
        Wbr,
        /// <summary>
        /// XML
        /// </summary>
        Xml
    }
}

#endif