/*
dotNetRDF is free and open source software licensed under the MIT License

-----------------------------------------------------------------------------

Copyright (c) 2009-2012 dotNetRDF Project (dotnetrdf-developer@lists.sf.net)

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is furnished
to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System;
using System.IO;

namespace VDS.RDF
{
    /// <summary>
    /// Interface to be implemented by Triple Store Readers
    /// </summary>
    public interface IStoreReader
    {

#if !NO_FILE
        /// <summary>
        /// Loads a RDF dataset into a Triple Store
        /// </summary>
        /// <param name="store">Triple Store</param>
        /// <param name="filename">File to load from</param>
        void Load(ITripleStore store, String filename);
#endif

        /// <summary>
        /// Loads a RDF dataset into a Triple Store
        /// </summary>
        /// <param name="store">Triple Store</param>
        /// <param name="input">Input to load from</param>
        void Load(ITripleStore store, TextReader input);

#if !NO_FILE
        /// <summary>
        /// Loads a RDF dataset using a RDF Handler
        /// </summary>
        /// <param name="handler">RDF Handler to use</param>
        /// <param name="filename">File to load from</param>
        void Load(IRdfHandler handler, String filename);
#endif

        /// <summary>
        /// Loads a RDF dataset using a RDF Handler
        /// </summary>
        /// <param name="handler">RDF Handler to use</param>
        /// <param name="input">Input to load from</param>
        void Load(IRdfHandler handler, TextReader input);

        /// <summary>
        /// Event which Readers can raise when they notice syntax that is ambigious/deprecated etc which can still be parsed
        /// </summary>
        event StoreReaderWarning Warning;
    }
}
